@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    Copyright 2010 Reto Zingg <g.d0b3rm4n@gmail.com>
+    Copyright 2010, 2011 Reto Zingg <g.d0b3rm4n@gmail.com>
 
  ***************************************************************************/
 
@@ -65,6 +65,9 @@ QmMultipleChoice::QmMultipleChoice(QWidget *parent) :
 
     connect(signalMapper, SIGNAL(mapped(int)), SLOT(slotClicked(int)));
 
+#ifndef Q_WS_MAEMO_5
+    vbox->addWidget(QmTrainer::m_leitnerWidget);
+#endif
     vbox->addLayout(vbox_label);
     setLayout(vbox);
 }
@@ -76,7 +79,7 @@ QmMultipleChoice::~QmMultipleChoice()
 
 void QmMultipleChoice::startTraining()
 {
-    if(QmTrainer::m_LessionIndex >= 0
+    if(QmTrainer::m_lessonIndexes->size() >= 1
        && QmTrainer::m_QuestionLanguage >= 0
        && QmTrainer::m_AnswerLanguage >= 0) {
         slotInit();
